@@ -31,8 +31,9 @@ class GameArea : public Lum::Object
 {
 private:
   Lum::OS::FontRef       minFont;
-  Lum::OS::FontRef       markFont;
+  Lum::OS::FontRef       minMarkFont;
   Lum::OS::FontRef       font;
+  Lum::OS::FontRef       markFont;
   Lum::OS::ColorRef      presetColor;
   Lum::OS::ColorRef      focusBackgroundColor;
   Lum::OS::ColorRef      errorColor;
@@ -64,8 +65,10 @@ public:
   void GetSolution(Sudoku& solution) const;
 
   void CalcSize();
+  void Layout();
 
-  Lum::OS::Font* FindFont(size_t size);
+  Lum::OS::Font* FindFont(Lum::OS::Font* minFont,
+                          size_t size);
 
   void Draw(int x, int y, size_t w, size_t h);
 
