@@ -24,13 +24,23 @@
 
 #include <Lum/Model/Action.h>
 #include <Lum/Model/Integer.h>
-#include <Lum/Model/String.h>
 
 class GenerateDialog : public Lum::Dlg::ActionDialog
 {
 private:
+  struct Level
+   {
+     std::wstring label;
+     size_t       points;
+
+     Level(const std::wstring& level,
+           size_t points);
+   };
+
+private:
+  std::list<Level>      levels;
   Lum::Model::ActionRef commitAction;
-  Lum::Model::StringRef points;
+  Lum::Model::SizeTRef  level;
   bool                  success;
 
 public:
